From: Andrew Morton <akpm@osdl.org>
To: Timo Hoenig <thoenig@suse.de>
Cc: acpi4asus-list@cerqueira.org, len.brown@intel.com,
acpi4asus-user@lists.sourceforge.net, linux-acpi@vger.kernel.org,
sziwan@hell.org.pl, marekw1977@yahoo.com.au
Subject: Re: [Acpi4asus-user] [patch 1/6] asus_acpi: W3000 support
Date: Sat, 1 Jul 2006 16:35:02 -0700 [thread overview]
Message-ID: <20060701163502.6a87e01a.akpm@osdl.org> (raw)
In-Reply-To: <1151795155.30054.25.camel@nouse.suse.de>
On Sun, 02 Jul 2006 01:05:55 +0200
Timo Hoenig <thoenig@suse.de> wrote:
> Hi Ricardo,
>
> On Sat, 2006-07-01 at 23:46 +0100, R Cerqueira wrote:
>
> > Since we're talking about applying patches, it would be nice if the W5F
> > patch I sent to the list back on April 26th could go in as well.
>
> Patches sent to the acpi4asus list should be reviewed there and
> afterwards sent to linux-acpi. As there was no reply to your mail on
> acpi4asus it got lost.
>
> > Anything wrong with it?
>
> Just had a short look at it and it looks fine to me. You may probably
> want to re-diff against Len's tree as I haven't checked if it still
> applies cleanly.
>
I'm carrying this version, whcih applies and builds OK.
From: Marek W <marekw1977@yahoo.com.au>
Add support for W3000 (W3V) and indirectly fixes an issue with kmilo under KDE
(it was triggering excessive LCD read error messages by querying asus_acpi
module) allowing people (I am probably the only one who tested this) with
W3000 to run kmilo.
Cc: Karol Kozimor <sziwan@hell.org.pl>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---
drivers/acpi/asus_acpi.c | 17 ++++++++++++++++-
1 file changed, 16 insertions(+), 1 deletion(-)
diff -puN drivers/acpi/asus_acpi.c~asus_acpi-w3000-support drivers/acpi/asus_acpi.c
--- a/drivers/acpi/asus_acpi.c~asus_acpi-w3000-support
+++ a/drivers/acpi/asus_acpi.c
@@ -138,6 +138,7 @@ struct asus_hotk {
S2x, //S200 (J1 reported), Victor MP-XP7210
W1N, //W1000N
W5A, //W5A
+ W3V, //W3030V
xxN, //M2400N, M3700N, M5200N, M6800N, S1300N, S5200N
//(Centrino)
END_MODEL
@@ -376,6 +377,17 @@ static struct model_data model_conf[END_
.display_get = "\\ADVG"},
{
+ .name = "W3V",
+ .mt_mled = "MLED",
+ .mt_wled = "WLED",
+ .mt_lcd_switch = xxN_PREFIX "_Q10",
+ .lcd_status = "\\BKLT",
+ .brightness_set = "SPLV",
+ .brightness_get = "GPLV",
+ .display_set = "SDSP",
+ .display_get = "\\INFB"},
+
+ {
.name = "xxN",
.mt_mled = "MLED",
/* WLED present, but not controlled by ACPI */
@@ -1097,6 +1109,8 @@ static int asus_model_match(char *model)
return A4G;
else if (strncmp(model, "W1N", 3) == 0)
return W1N;
+ else if (strncmp(model, "W3V", 3) == 0)
+ return W3V;
else if (strncmp(model, "W5A", 3) == 0)
return W5A;
else
@@ -1200,9 +1214,10 @@ static int asus_hotk_get_info(void)
hotk->methods->mt_wled = NULL;
/* L5D's WLED is not controlled by ACPI */
else if (strncmp(string, "M2N", 3) == 0 ||
+ strncmp(string, "W3V", 3) == 0 ||
strncmp(string, "S1N", 3) == 0)
hotk->methods->mt_wled = "WLED";
/* M2N and S1N have a usable WLED */
else if (asus_info) {
if (strncmp(asus_info->oem_table_id, "L1", 2) == 0)
hotk->methods->mled_status = NULL;
_
next prev parent reply other threads:[~2006-07-01 23:35 UTC|newest]
Thread overview: 11+ messages / expand[flat|nested] mbox.gz Atom feed top
2006-06-30 18:10 [patch 1/6] asus_acpi: W3000 support Brown, Len
2006-06-30 19:31 ` Karol Kozimor
2006-07-01 14:50 ` [Acpi4asus-user] " Timo Hoenig
2006-07-01 22:46 ` R Cerqueira
2006-07-01 23:05 ` Timo Hoenig
2006-07-01 23:35 ` Andrew Morton [this message]
2006-07-02 9:46 ` Johannes Engel
2006-07-02 10:35 ` Timo Hoenig
2006-07-02 10:33 ` Timo Hoenig
2006-07-01 23:06 ` Karol Kozimor
-- strict thread matches above, loose matches on Subject: below --
2006-07-01 16:26 Brown, Len
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20060701163502.6a87e01a.akpm@osdl.org \
--to=akpm@osdl.org \
--cc=acpi4asus-list@cerqueira.org \
--cc=acpi4asus-user@lists.sourceforge.net \
--cc=len.brown@intel.com \
--cc=linux-acpi@vger.kernel.org \
--cc=marekw1977@yahoo.com.au \
--cc=sziwan@hell.org.pl \
--cc=thoenig@suse.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1200,9 +1214,10 @@ static int asus_hotk_get_info(void)
strncmp(string, "S1N", 3) == 0)
hotk->methods->mt_wled = "WLED";
- /* M2N and S1N have a usable WLED */
+ /* M2N, S1N and W3V have a usable WLED */
else if (asus_info) {
if (strncmp(asus_info->oem_table_id, "L1", 2) == 0)
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox